<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
// use Illuminate\Contracts\Support\Renderable;
use App\Models\BoycottProduct;
use App\Models\Position;
use Inertia\Inertia;
use App\Traits\UploadTrait;

class PhrasesController extends Controller
{

    /**
     * Display a listing of the resource.
     * @return Renderable
     */
    use UploadTrait;
    // use boycott_productservice;
    public function __construct()
    {
        $this->middleware('permission:boycott_products-create', ['only' => ['create', 'store']]);
        $this->middleware('permission:boycott_products-update',   ['only' => ['edit', 'update']]);
        $this->middleware('permission:boycott_products-read',   ['only' => ['show', 'index']]);
        $this->middleware('permission:boycott_products-delete',   ['only' => ['destroy']]);
        $this->middleware('permission:boycott_products-eye',   ['only' => ['eye']]);
    }
    public function eye($id)
    {
        $active = BoycottProduct::find($id);
        if ($active->active == 1) {
            $active->active = 0;
        } else {
            $active->active = 1;
        }
        $active->save();
        // return $active->active;
        return response()->json(["success" => true, "eye" => $active], 200);
    }
    public function index(Request $request)
    {
        $per_page = $request->itemsPerPage ?? 20;
        $orderBy = $request->sortBy ?? "id";
        $orderDir = $request->sortDesc ?? "desc";
        $boycott_products = BoycottProduct::orderBy($orderBy, $orderDir)
            ->filter($request->only('search'))
            ->paginate($per_page)
            ->appends(['search' => $request->only('search')]);
        if ($request->wantsJson()) {
            return $boycott_products;
        }
        return Inertia::render("Admin/BoycottProduct/Index", ["boycott_products" => $boycott_products]);
    }

    /**
     * Show the form for creating a new resource.
     * @return Renderable
     */
    public function create()
    {

        return Inertia::render("Admin/BoycottProduct/Create", ["categories" => $categories, "trademarks" => $trademarks, "positions" => $positions, "sizes" => $sizes, "colors" => $colors, ]);
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Renderable
     */
    public function store(Request $request)
    {

        $request->validate([
            'name' => 'required|string|unique:boycott_products,name',
            'order' => 'required|integer',
            'main_image'          => 'required',
            'main_image2'         => 'required',
            'price'               => 'required',
            'old_price'           => 'integer',
            'count'               => 'integer',
            'featured'            => 'required',
            'description'         => 'required',
            'category_id'         => 'required|integer',
        ]);
        $boycott_products = new BoycottProduct();
        $boycott_products->user_id = auth()->user()->id;
        $boycott_products->name = $request->name;
        $boycott_products->price = $request->price;
        $boycott_products->old_price = $request->old_price;
        $boycott_products->count = $request->count;
        $boycott_products->category_id = $request->category_id;
        $boycott_products->featured = $request->featured;
        $boycott_products->description = $request->description;
        $boycott_products->image = $this->storeImage($request['main_image'], 'images/boycott_products');
        $boycott_products->save();
        return redirect()->route("boycott_products.index")->with('success', 'تم اضافة  بنجاح');
    }
    /**
     * Show the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function show($id)
    {
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function edit($id)
    {
        $boycott_products =  BoycottProduct::find($id);
        return Inertia::render("Admin/BoycottProduct/Edit", ["boycott_products" => $boycott_products]);
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Renderable
     */
    public function update(Request $request, $id)
    {
        $request->validate([
            'name'     => 'required|string|unique:boycott_products,name,' . $id,
            'order'    => 'required|integer',
            'image'    => 'required',
        ]);
        $boycott_products =  BoycottProduct::find($id);
        // $boycott_products->user_id   = auth()->user()->id;
        $boycott_products->name      = $request->name;
        $boycott_products->order     = $request->order;
        if ($request['image'] != null)
            $boycott_products->image = $this->updateImage($request['image'], 'images/boycott_products', $boycott_products->image);
        $boycott_products->save();
        return redirect()->route("boycott_products.index")->with('success', 'تم التعديل   بنجاح');
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Renderable
     */
    public function destroy($id)
    {
        $boycott_products = BoycottProduct::find($id);
        $this->deleteImage($boycott_products->image);
        $boycott_products->delete();
        return true;
    }
}
