<?php

namespace App\Http\Controllers\Admin;
use App\Actions\Fortify\PasswordValidationRules;
use App\Http\Controllers\Controller;
use App\Http\Requests\UserRequest;
use App\Http\Resources\UserDetailResource;
use App\Traits\OrginaizePermissionTrait;
use App\Models\Role;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Laravel\Fortify\Rules\Password;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;
use Inertia\Inertia;
use Monarobase\CountryList\CountryListFacade;

class UserController extends Controller
{
    use PasswordValidationRules;
    use OrginaizePermissionTrait;
    public function __construct()
    {
        $this->middleware('permission:users-create', ['only' => ['create', 'store']]);
        $this->middleware('permission:users-update',   ['only' => ['edit', 'update']]);
        $this->middleware('permission:users-read',   ['only' => ['show', 'index']]);
        $this->middleware('permission:users-delete',   ['only' => ['destroy']]);
        $this->middleware('permission:users-eye',   ['only' => ['eye']]);
    }

    public function eye($id)
    {
        $active = User::find($id);

        if ($active->active == 1) {
            $active->active = 0;
        } else {
            $active->active = 1;
        }
            $active->save();
        return response()->json(["success" => true, "eye" => $active], 200);
    }

    public function index(Request $request)
    {


        // $user=User::find(11);

        // dd( array_column($user->allPermissions()->toArray(),"display_name"));

        $per_page = $request->itemsPerPage ?? 20;
        $orderBy = $request->sortBy ?? "id";
        $orderDir = $request->sortDesc ?? "desc";
        // $orderBy = $request->sortBy ?? "id";
        // $orderDir = $request->sortDesc==null ? "desc" :( $request->sortDesc == false ?"asc" : "desc");

        // $users = User::where("id", "!=", auth()->user()->id)
        //     ->orderBy($orderBy, $orderDir)

        //     ->filter($request->only('search'))
        //     ->paginate($per_page)
        //     ->appends(['search' => $request->only('search')])
        //     ;;

           $users=$this->filterUsersForCurrentUser()->toQuery();
           $users= $users->where("id", "!=", auth()->user()->id)
                ->orderBy($orderBy, $orderDir)

                ->filter($request->only('search'))
                ->paginate($per_page)
                ->appends(['search' => $request->only('search')])
                ;

        if ($request->wantsJson()) {

            return $users;
        }


        return Inertia::render("Admin/Users/Index", ["allusers" => $users]);
    }

    public function create()
    {


        // $user_permissions = auth()->user()->userPermissions;

        $roles =    $this->filterRolesForCurrentUser()->map(function ($d) {

            return collect($d->toArray())
                ->only(['id', 'display_name'])
                ->all();
        })->values();

        $permissions = $this->OrginaizePermission();



        return Inertia::render("Admin/Users/Create", ["roles" => $roles, 'permissions' => $permissions]);
    }
    // public function show($id)
    // {
    //     // return redirect()->route("users.index")->with("error","هذا الصفحة غير موجودة");
    //     $user = User::find($id);
    //     if (!$user) {
    //         // return redirect()->route("job_ads.index")->with('error', 'اعلان الوظيفه هذا غير موجود');
    //         return redirect()->back()->with('error', 'هذا المستخدم غير موجود');
    //     }

    //     return Inertia::render('Admin/Users/Show', ["userData" => $user ]);
    // }
    public function store(UserRequest $request)
    {
        $role = Role::find($request->role);
        if ($request->role != null && !$role) {
            return redirect()->route("users.index")->with("error", "هذا الدور غير موجود");
        }
        $user = new User();
        $user->name = $request->name;
        $user->email = $request->email;
        $user->password = Hash::make($request->password);
        $user->email_verified_at = now();
        $user->save();
        $user->roles()->sync($role);
        $user->permissions()->sync($request->selected_permission);
        return redirect()->route("users.index")->with('success', 'تم اضافة المستخدم بنجاح');
    }
    public function edit($id)
    {
        $user = User::find($id);

        if (!$user) {
            return redirect()->route("users.index")->with('error', 'هذا المستخم غير موجود');
        }
        if (auth()->id() == $user->id) {
            return redirect()->route("users.index")->with('error', ' لايمكنك تعديل بياناتك الشخصية من هنا يمكنك تعديلها من صفحة البروفايل ');
        }
        if(!$this->filterUserForCurrentUser($user)){
            return redirect()->route("users.index")->with('error', 'ليس لديك صلاحيات لتعديل بيانات هذا المستخدم ');
        }
        $roles = $this->filterRolesForCurrentUser()->map(function ($d) {
            return collect($d->toArray())
                ->only(['id', 'display_name'])
                ->all();
        })->values() ;
        $permissions = $this->OrginaizePermission() ;
        $user_permissions_ids = array_column($user->permissions->toArray(), "id");
        // $user_permissions_ids=$user->userPermissions;
        $user_role = $user->roles->first();
        return Inertia::render("Admin/Users/Edit", [
            "userInfo" => $user,
            "roles" => $roles,
            "permissions" => $permissions,
            "user_role" => $user_role,
            "user_permissions_ids" => $user_permissions_ids
        ]);
    }
    public function update(UserRequest $request, $id)
    {
        $user = User::find($id);
        if (!$user) {
            return redirect()->route("users.index")->with('error', 'هذا المستخم غير موجود');
        }
        if (auth()->id() == $user->id) {
            return redirect()->route("users.index")->with('error', ' لايمكنك تعديل بياناتك الشخصية من هنا يمكنك تعديلها من صفحة البروفايل ');
        }
        if(!$this->filterUserForCurrentUser($user)){
            return redirect()->route("users.index")->with('error', 'ليس لديك صلاحيات لتعديل بيانات هذا المستخدم ');
        }
        $role = Role::find($request->role);
        if ($request->role != null && !$role) {
            return redirect()->route("users.index")->with("error", "هذا الدور غير موجود");
        }
        // dd($role);
        $passwordValidation = "";
        if ($request->password || $request->password_confirmation) {
            $passwordValidation = new Password;
        }
        // Validator::make($request->all(), [
        //     'name' => ['required', 'string', 'max:255'],
        //     'email' => ['required', 'string', 'email', 'max:255', Rule::unique('users')->ignore($id)],
        //     'password' => ['required_unless:password_confirmation,' . $request->password_confirmation,   $passwordValidation],
        //     'password_confirmation' => ['same:password',   $passwordValidation],

        // ])->validate();
        if ($request->password) {
            $user->password = Hash::make($request->password);
        }
        $user->name = $request->name;
        $user->email = $request->email;
        $user->save();
        $user->roles()->sync($role);
        $user->permissions()->sync($request->selected_permission);
        $user->save();
        return redirect()->route("users.index")->with('success', 'تم تعديل بيانات المستخدم بنجاح');
    }
    public function destroy($id)
    {
        $user = User::find($id);
        if (!$user) {
            return redirect()->route("users.index")->with('error', 'هذا المستخم غير موجود');
        }
        if(!$this->filterUserForCurrentUser($user)){
            return redirect()->route("users.index")->with('error', 'ليس لديك صلاحيات لحذف  هذا المستخدم ');
        }
        if (auth()->id() == $user->id) {
            return redirect()->route("users.index")->with('error', ' لايمكنك حذف بياناتك الشخصية من هنا يمكنك حذفها من صفحة البروفايل ');
        }
        $user->delete();
        return redirect()->route("users.index")->with('success', 'تم حذف بيانات المستخدم بنجاح');
    }
}
